@@ -1,6 +1,7 @@
-__version__ = "2.0.1"
+__version__ = "2.0.2"
 from janda.pururin import Pururin
 from janda.nhentai import Nhentai
 from janda.hentaifox import Hentaifox
 from janda.hentai2read import Hentai2read
-from janda.utils.parser import *
\ No newline at end of file
+## import from utils 
+from janda.utils import *
\ No newline at end of file
