@@ -1,6 +1,6 @@
 import requests
 import json
-from janda.utils.parser import *
+from .utils.parser import *
 
 BASE_URL = Api()
 
